@@ -1,6 +1,6 @@
 # loosely inspired by https://github.com/lodimasq/batch-checkpoint-merger/blob/master/batch_checkpoint_merger/main.py#L71
 
-from sdkit.utils import load_tensor_file, save_tensor_file
+from sdkit.utils import load_tensor_file, save_tensor_file, log
 
 def merge_models(model0_path: str, model1_path: str, ratio: float, out_path: str, use_fp16=True):
     '''
@@ -11,8 +11,19 @@ def merge_models(model0_path: str, model1_path: str, ratio: float, out_path: str
               0 means only the first model will be used.
     '''
 
+    log.info(f'[cyan]Merge models:[/cyan] Merging {model0_path} and {model1_path}, ratio {ratio}')
     merged = merge_two_models(model0_path, model1_path, ratio, use_fp16)
-    save_tensor_file(merged, out_path)
+
+    log.info(f'[cyan]Merge models:[/cyan] ... saving as {out_path}')
+
+    if out_path.lower().endswith(".safetensors"):
+        # elldrethSOg4060Mix_v10.ckpt contains a state_dict key among all the tensors, but safetensors
+        # assumes that all entries are tensors, not dicts => remove the key
+        if 'state_dict' in merged:
+           del merged['state_dict']
+        save_tensor_file(merged, out_path)
+    else:
+        save_tensor_file({'state_dict':merged}, out_path)
 
 # do this pair-wise, to avoid having to load all the models into memory
 def merge_two_models(model0, model1, alpha, use_fp16=True):
@@ -41,11 +52,13 @@ def merge_two_models(model0, model1, alpha, use_fp16=True):
         if 'model' in key and key not in model0:
             model0[key] = model1[key]
 
-    # unload model1 from memory
-    del model1
 
     if use_fp16:
         for key, val in model0.items():
-            model0[key] = val.half()
+            if 'model' in key:
+                model0[key] = val.half()
+
+    # unload model1 from memory
+    del model1
 
     return model0
